DmVerityTargetOptionalParams

Struct DmVerityTargetOptionalParams 

pub struct DmVerityTargetOptionalParams {
    pub ignore_zero_blocks: bool,
    pub restart_on_corruption: bool,
}
Optional construction parameters for a dm-verity target.

These correspond to the optional target parameters in Linux dm-verity. They default to false if all features are disabled.

See https://docs.kernel.org/admin-guide/device-mapper/verity.html

Fields

ignore_zero_blocks: bool

If set, blocks containing only zeroes will bypass verification and always return zeroes instead.

restart_on_corruption: bool

If set, the system will restart if data corruption is detected.