pub struct DmVerityTargetParams {
pub version: String,
pub block_device_path: String,
pub hash_device_path: String,
pub data_block_size: u64,
pub hash_block_size: u64,
pub num_data_blocks: u64,
pub hash_start_block: u64,
pub hash_algorithm: HashAlgorithm,
pub root_digest: String,
pub salt: String,
pub optional_params: DmVerityTargetOptionalParams,
}Expand description
Construction parameters for a dm-verity target.
Mirrors the mandatory parameters passed to the dm-verity target in Linux, along with optional
DmVerityTargetOptionalParams.
See https://docs.kernel.org/admin-guide/device-mapper/verity.html
Fields
version: StringThe version of the dm-verity target.
block_device_path: StringThe path to the data block device to be verified.
hash_device_path: StringThe path to the block device containing the Merkle tree hashes.
data_block_size: u64The size of a data block in bytes.
hash_block_size: u64The size of a hash block in bytes.
num_data_blocks: u64The total number of data blocks on the data device.
hash_start_block: u64The root block index on the hash device where the Merkle tree begins.
hash_algorithm: HashAlgorithmThe cryptographic hash algorithm used (e.g., SHA256 or SHA512).
root_digest: StringThe hexadecimal encoded root digest of the Merkle tree. This hash should be trusted.
salt: StringThe hexadecimal encoded salt used when hashing blocks.
optional_params: DmVerityTargetOptionalParamsOptional target parameters.